Skip to contents

Get App data

Get App data

Details

R6 class that allows to get the information needed for an User session of the app.

Methods

Inherited methods


Method new()

Start a session of app data based on an user email

Usage

AppData$new(email = Sys.getenv("REPORTES_EMAIL"))

Arguments

email

The email the user started the session with.


Method clone()

The objects of this class are cloneable with this method.

Usage

AppData$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.