Skip to contents

Clase R6 para manejar la base de datos

Clase R6 para manejar la base de datos

Details

Una base de datos puede ejecutar y obtener querys

Methods


Method new()

Start the DB Manager

Usage

DBManager$new(use_tibble = TRUE)

Arguments

use_tibble

Whether print the results of DbGetQuery() as a tibble or not. Default TRUE


Method db_execute_statement()

Analog to DBI::dbExecute()

Usage

DBManager$db_execute_statement(...)

Arguments

...

Objects passed to glue::glue_sql() with the exception of the .con argument.


Method db_get_query()

Analog to DBI::dbGetQuery()

Usage

DBManager$db_get_query(...)

Arguments

...

Objects passed to glue::glue_sql() with the exception of the .con argument.


Method db_make_query()

Construct the query to be passed to DBI::dbGetQuery(). Useful for debugging and subquery construction.

Usage

DBManager$db_make_query(...)

Arguments

...

Objects passed to glue::glue_sql() with the exception of the .con argument.


Method clone()

The objects of this class are cloneable with this method.

Usage

DBManager$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.