Skip to contents

Get Group data

Get Group data

Details

R6 class that allows to get the Group information.

Public fields

group_selected

ID of the group to be used in the board, by default is the favorite group in group_users

Active bindings

groups

List containing the group affiliations of the User

group_users

List containing the user list of the group The info is shown following the User's group role.

group_units

List containing the group's measurement units. Older units are shown first.

Methods

Inherited methods


Method new()

Start a Group based on an user email

Usage

Group$new(email = Sys.getenv("REPORTES_EMAIL"))

Arguments

email

The email the user started the session with.


Method group_initialize()

Initialize a group for a new user

Usage

Group$group_initialize(org_id)

Arguments

org_id

The id of the organisation on which the statement will be executed


Method group_add()

Add a group to the database

Usage

Group$group_add(org_id, group_title, group_description)

Arguments

org_id

The id of the organisation on which the statement will be executed

group_title

The new title of the group

group_description

The new description of the group


Method group_delete()

Remove a group from the database

Usage

Group$group_delete(group_id)

Arguments

group_id

The id of the group on which the statement will be executed


Method group_edit()

Edit group metadata

Usage

Group$group_edit(group_id, group_title, group_description)

Arguments

group_id

The id of the group on which the statement will be executed

group_title

The new title of the group

group_description

The new description of the group


Method group_user_add()

Add an user to a group

Usage

Group$group_user_add(
  group_id,
  user_id,
  user_color = "white",
  group_role = "user"
)

Arguments

group_id

The id of the group on which the statement will be executed

user_id

The id of the user on which the statement will be executed

user_color

The color of the user's cards

group_role

The role for the user in the group


Method group_user_delete()

Delete an user from a group

Usage

Group$group_user_delete(group_id, user_id)

Arguments

group_id

The id of the group on which the statement will be executed

user_id

The id of the user on which the statement will be executed


Method group_user_edit()

Edit the role of a user inside a group and related information

Usage

Group$group_user_edit(group_id, user_id, user_color, group_role)

Arguments

group_id

The id of the group on which the statement will be executed

user_id

The id of the user on which the statement will be executed

user_color

The color of the user's cards

group_role

The role for the user in the group


Method group_select()

Select a group for use in the board

Usage

Group$group_select(group_id)

Arguments

group_id

The id of the group on which the statement will be executed


Method group_unit_add()

Add a measurement unit for a group

Usage

Group$group_unit_add(
  unit_title,
  unit_description = "",
  unit_type,
  unit_icon = "file"
)

Arguments

unit_title

The title of a group's measurement unit

unit_description

The description of a group's measurement unit

unit_type

The type of a group's measurement unit. One of ("report", "task")

unit_icon

The icon of a group's measurement unit. Should be the compatible with fontawesome::fa().


Method group_unit_edit()

Edit a measurement unit from a group

Usage

Group$group_unit_edit(
  unit_id,
  unit_title,
  unit_description,
  unit_type,
  unit_icon
)

Arguments

unit_id

The id of a group's measurement unit

unit_title

The title of a group's measurement unit

unit_description

The description of a group's measurement unit

unit_type

The type of a group's measurement unit. One of ("report", "task")

unit_icon

The icon of a group's measurement unit. Should be the compatible with fontawesome::fa().


Method group_unit_delete()

Delete a measurement unit from a group

Usage

Group$group_unit_delete(unit_id)

Arguments

unit_id

The id of a group's measurement unit


Method clone()

The objects of this class are cloneable with this method.

Usage

Group$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.