Get user information
Get user information
Details
R6 class that allows to get the user information.
Public fields
user
List containing the user info.
Methods
Inherited methods
Method new()
Start User
Arguments
email
The email the user started the session with.
Method user_add()
Add a new user to the database
Usage
User$user_add(name, last_name, email)
Arguments
name
Name to be inserted as user metadata.
last_name
Last name to be inserted as user metadata.
email
The email the user started the session with.
Method user_delete()
Delete a user from the database
Usage
User$user_delete(user_id)
Arguments
user_id
ID of the user to edit or delete.
Method user_edit_names()
Change the name and last name of the User
Usage
User$user_edit_names(user_id, name, last_name)
Arguments
user_id
ID of the user to edit or delete.
name
Name to be inserted as user metadata.
last_name
Last name to be inserted as user metadata.
Method clone()
The objects of this class are cloneable with this method.
Arguments
deep
Whether to make a deep clone.